@@ -72,7 +72,7 @@ installPackages+=(libusbx-devel)
 # speech-dispatcher-devel / flite-devel for QtSpeech
 installPackages+=(speech-dispatcher-devel)
 installPackages+=(flite-devel)
-# Python for pyside
+# Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
 installPackages+=(python3.11)
 installPackages+=(python3.11-pip)
 installPackages+=(python3.11-devel)
@@ -89,6 +89,7 @@ installPackages+=(libXtst-devel)
 installPackages+=(libxshmfence-devel)
 installPackages+=(nspr-devel)
 installPackages+=(nss-devel)
+installPackages+=(python3-html5lib)
 installPackages+=(libatomic)
 installPackages+=(mesa-libgbm-devel-21.3.4-1.el8.x86_64)
 # For Android builds
@@ -119,7 +120,6 @@ installPackages+=(libxkbcommon-devel)
 installPackages+=(libxkbcommon-x11-devel)
 # xcb-util-* libraries
 installPackages+=(xcb-util)
-installPackages+=(xcb-util-devel)
 installPackages+=(xcb-util-image-devel)
 installPackages+=(xcb-util-keysyms-devel)
 installPackages+=(xcb-util-wm-devel)
@@ -155,8 +155,6 @@ installPackages+=(zip)
 installPackages+=(perl-IPC-Cmd)
 # password management support for Qt Creator
 installPackages+=(libsecret-devel)
-# For tst_license.pl with all the machines generating SBOM
-installPackages+=(perl-JSON)
 
 sudo yum -y install "${installPackages[@]}"
 
@@ -170,13 +168,15 @@ sudo pip config --user set global.index https://ci-files01-hki.ci.qt.io/input/py
 sudo pip config --user set global.extra-index-url https://pypi.org/simple/
 
 sudo pip3 install virtualenv wheel
-sudo python3.11 -m pip install virtualenv wheel html5lib
+# Just make sure we have virtualenv to run with python3.8 -m virtualenv
+sudo python3.11 -m pip install virtualenv wheel
 sudo python3.11 -m pip install -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
 # For now we don't set QT_SBOM_PYTHON_APPS_PATH here, and rely on the build system to find the
 # system python3.11.
 
 sudo /usr/bin/pip3 install wheel
 sudo /usr/bin/pip3 install dataclasses
+sudo /usr/bin/pip3 install -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
 
 gccVersion="$(gcc --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "GCC = $gccVersion" >> versions.txt
